@@ -59,8 +59,9 @@ class AvahiApp(app_module.App):
         self.add(packages)
 
         domain_type = DomainType('domain-type-local',
-                                 _('Local Network Domain'), 'names:hostname',
-                                 can_have_certificate=False)
+                                 _('Local Network Domain'),
+                                 configuration_url='names:hostname',
+                                 can_have_certificate=False, priority=10)
         self.add(domain_type)
 
         firewall = Firewall('firewall-avahi', info.name, ports=['mdns'],
