@@ -4,9 +4,8 @@ Decorators for the backup views.
 """
 
 import functools
-import os
 
-from . import SESSION_PATH_VARIABLE
+from . import privileged, SESSION_PATH_VARIABLE
 
 
 def delete_tmp_backup_file(function):
@@ -15,12 +14,12 @@ def delete_tmp_backup_file(function):
     XXX: Implement a better way to delete uploaded files.
 
     """
+
     @functools.wraps(function)
     def wrapper(request, *args, **kwargs):
         path = request.session.get(SESSION_PATH_VARIABLE, None)
         if path:
-            if os.path.isfile(path):
-                os.remove(path)
+            privileged.remove_uploaded_archive(path)
             del request.session[SESSION_PATH_VARIABLE]
         return function(request, *args, **kwargs)
 
