@@ -4,7 +4,7 @@ Django forms for bepasty app.
 """
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from plinth.modules import bepasty
 
