@@ -4,9 +4,11 @@ Forms for Coturn app.
 """
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.core.exceptions import ValidationError
+from django.utils.translation import gettext_lazy as _
 
 from plinth.modules import coturn
+from plinth.modules.coturn.components import TurnConfiguration
 
 
 def get_domain_choices():
@@ -14,6 +16,13 @@ def get_domain_choices():
     return ((domain, domain) for domain in coturn.get_available_domains())
 
 
+def turn_uris_validator(turn_uris):
+    """Validate list of STUN/TURN Server URIs."""
+    uris = [uri for uri in turn_uris.split('\r\n') if uri]
+    if not TurnConfiguration.validate_turn_uris(uris):
+        raise ValidationError(_('Invalid list of STUN/TURN Server URIs'))
+
+
 class CoturnForm(forms.Form):
     """Form to select a TLS domain for Coturn."""
 
