@@ -7,8 +7,8 @@ See: https://rspamd.com/doc/modules/dkim_signing.html
 import pathlib
 import re
 import shutil
-import subprocess
 
+from plinth import action_utils
 from plinth.actions import privileged
 from plinth.privileged import service as service_privileged
 
@@ -30,9 +30,9 @@ def get_dkim_public_key(domain: str) -> str:
     """Privileged action to get the public key from DKIM key."""
     _validate_domain_name(domain)
     key_file = _keys_dir / f'{domain}.dkim.key'
-    output = subprocess.check_output(
+    output = action_utils.run(
         ['openssl', 'rsa', '-in',
-         str(key_file), '-pubout'], stderr=subprocess.DEVNULL)
+         str(key_file), '-pubout'], check=True).stdout
     return ''.join(output.decode().splitlines()[1:-1])
 
 
@@ -54,7 +54,7 @@ def setup_dkim(domain: str):
 
     # Ed25519 is widely *not* accepted as of 2022-01. See:
     # https://serverfault.com/questions/1023674
-    subprocess.run([
+    action_utils.run([
         'rspamadm', 'dkim_keygen', '-t', 'rsa', '-b', '2048', '-s', 'dkim',
         '-d', domain, '-k', (str(key_file))
     ], check=True)
