@@ -20,9 +20,7 @@ from django.conf import settings
 from django.http import Http404
 from django.urls import re_path
 
-from plinth import cfg
-from plinth import menu as menu_module
-from plinth import module_loader
+from plinth import cfg, module_loader
 from plinth.modules import help as help_module
 from plinth.modules.help import views
 
@@ -57,9 +55,8 @@ def fixture_developer_configuration():
 
 
 @pytest.fixture(name='menu', autouse=True)
-def fixture_menu():
+def fixture_menu(test_menu):
     """Initialized menu module."""
-    menu_module.init()
     help_module.HelpApp()  # Create all menu components
 
 
@@ -172,12 +169,12 @@ MANUAL_PAGES = ('Apache_userdir', 'APU', 'Backups', 'BananaPro', 'BeagleBone',
                 'DateTime', 'Debian', 'Deluge', 'Developer', 'Diagnostics',
                 'Download', 'DynamicDNS', 'ejabberd', 'Firewall',
                 'freedombox-manual', 'GettingHelp', 'GitWeb', 'Hardware',
-                'I2P', 'Ikiwiki', 'Infinoted', 'Introduction', 'JSXC',
-                'LetsEncrypt', 'Maker', 'MatrixSynapse', 'MediaWiki',
-                'Minetest', 'MiniDLNA', 'Mumble', 'NameServices', 'Networks',
-                'OpenVPN', 'OrangePiZero', 'PageKite', 'pcDuino3',
-                'Performance', 'PineA64+', 'PioneerEdition', 'Plinth', 'Power',
-                'Privoxy', 'Quassel', 'QuickStart', 'Radicale', 'RaspberryPi2',
+                'Ikiwiki', 'Infinoted', 'Introduction', 'JSXC', 'LetsEncrypt',
+                'Maker', 'MatrixSynapse', 'MediaWiki', 'Minetest', 'MiniDLNA',
+                'Mumble', 'NameServices', 'Networks', 'OpenVPN',
+                'OrangePiZero', 'PageKite', 'pcDuino3', 'Performance',
+                'PineA64+', 'PioneerEdition', 'Plinth', 'Power', 'Privoxy',
+                'Quassel', 'QuickStart', 'Radicale', 'RaspberryPi2',
                 'RaspberryPi3B+', 'RaspberryPi3B', 'RaspberryPi4B',
                 'ReleaseNotes', 'Rock64', 'RockPro64', 'Roundcube', 'Samba',
                 'Searx', 'SecureShell', 'Security', 'ServiceDiscovery',
