@@ -25,6 +25,11 @@ _description = [
     format_lazy(
         _('<a href="{coturn_url}">Coturn</a> is required to '
           'use Janus.'), coturn_url=reverse_lazy('coturn:index')),
+    format_lazy(
+        _('<strong>Note:</strong> This app receives frequent feature updates. '
+          'It can only be installed if frequent feature updates is enabled in '
+          'the <a href="{upgrades_url}">Software Update</a> app.'),
+        upgrades_url=reverse_lazy('upgrades:index')),
 ]
 
 
@@ -56,9 +61,9 @@ class JanusApp(app_module.App):
         self.add(shortcut)
 
         packages = Packages('packages-janus', [
-            'janus', 'libjs-jquery', 'libjs-bootbox', 'libjs-bootstrap',
-            'libjs-bootswatch', 'libjs-janus-gateway', 'libjs-jquery-blockui',
-            'libjs-spin.js', 'libjs-toastr', 'libjs-webrtc-adapter'
+            'janus', 'libjs-jquery', 'libjs-bootbox', 'libjs-bootstrap5',
+            'libjs-janus-gateway', 'libjs-jquery-blockui', 'libjs-toastr',
+            'libjs-webrtc-adapter', 'node-popper2'
         ])
         self.add(packages)
 
