@@ -8,7 +8,7 @@ from django.urls import re_path
 from . import views
 
 urlpatterns = [
-    re_path(r'^sys/power/$', views.index, name='index'),
+    re_path(r'^sys/power/$', views.PowerAppView.as_view(), name='index'),
     re_path(r'^sys/power/restart$', views.restart, name='restart'),
     re_path(r'^sys/power/shutdown$', views.shutdown, name='shutdown'),
 ]
