@@ -51,17 +51,16 @@ class ShadowsocksServerApp(app_module.App):
         self.add(info)
 
         menu_item = menu.Menu('menu-shadowsocks-server', info.name,
-                              info.short_description, info.icon_filename,
+                              info.icon_filename, info.tags,
                               'shadowsocksserver:index',
                               parent_url_name='apps')
         self.add(menu_item)
 
         shortcut = frontpage.Shortcut(
-            'shortcut-shadowsocks-server', info.name,
-            short_description=info.short_description, icon=info.icon_filename,
+            'shortcut-shadowsocks-server', info.name, icon=info.icon_filename,
             description=info.description, manual_page=info.manual_page,
             configure_url=reverse_lazy('shadowsocksserver:index'),
-            login_required=True)
+            tags=info.tags, login_required=True)
         self.add(shortcut)
 
         packages = Packages('packages-shadowsocks-server',
