@@ -3,8 +3,12 @@
 Application manifest for snapshot.
 """
 
+from django.utils.translation import gettext_lazy as _
+
 backup = {
     'config': {
         'files': ['/etc/snapper/configs/root', '/etc/default/snapper']
     }
 }
+
+tags = [_('Periodic'), _('Restore'), _('Known good state'), _('Btrfs')]
