@@ -16,8 +16,6 @@ urlpatterns = [
     re_path(r'^sys/users/create/$', views.UserCreate.as_view(), name='create'),
     re_path(r'^sys/users/(?P<slug>[\w.@+-]+)/edit/$',
             non_admin_view(views.UserUpdate.as_view()), name='edit'),
-    re_path(r'^sys/users/(?P<slug>[\w.@+-]+)/delete/$',
-            views.UserDelete.as_view(), name='delete'),
     re_path(r'^sys/users/(?P<slug>[\w.@+-]+)/change_password/$',
             non_admin_view(views.UserChangePassword.as_view()),
             name='change_password'),
