@@ -4,7 +4,7 @@ FreedomBox app for configuring Zoph.
 """
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class ZophForm(forms.Form):
